import Vue from 'vue'
import Router from 'vue-router'
const _import = require('./_import_' + process.env.NODE_ENV)
// in development-env not use lazy-loading, because lazy-loading too many pages will cause webpack hot update too slow. so only in production use lazy-loading;
// detail: https://panjiachen.github.io/vue-element-admin-site/#/lazy-loading

Vue.use(Router)

/* Layout */
import Layout from '../views/layout/Layout'

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* redirect: noredirect           if `redirect:noredirect` will no redirct in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
  }
**/
export const constantRouterMap = [
  { path: '/login', component: _import('login/index'), hidden: true },
  { path: '/401', component: _import('errorPage/401'), hidden: true },
  { path: '/404', component: _import('errorPage/404'), hidden: true },

  {
    path: '',
    component: Layout,
    redirect: 'dashboard',
    name: 'Dashboard',
    children: [
      {
        path: 'dashboard',
        name: 'dashboard',
        component: _import('dashboard/index'),
        meta: {
          title: '首頁',
          icon: 'dashboard',
          noCache: true
          // role: ['dd']
        }
      }
    ]
  },
  {
    path: '/gambleMember',
    component: Layout,
    redirect: '/gambleMember/index',
    children: [
      {
        path: 'index',
        name: 'GambleMember',
        component: _import('gambleMember/index'),
        meta: {
          title: '會員管理',
          icon: 'form'
          // role: ['dd']
        }
      }
    ]
  },
  {
    path: '/gambleGameBucket',
    component: Layout,
    redirect: '/gambleGameBucket/index',
    children: [
      {
        path: 'index',
        name: 'GambleGameBucket',
        component: _import('gambleGameBucket/index'),
        meta: {
          title: '每局紀錄',
          icon: 'table'
          // role: ['dd']
        },
        children: [
          {
            path: '/gambleGameBucket/index/detail',
            name: 'GambleGameBucketDetail',
            component: _import('gambleGameBucket/detail/index'),
            hidden: true,
            meta: {
              title: '詳細紀錄'
              // role: ['dd']
            }
          }
        ]
      }
    ]
  },
  // {
  //   path: '/example',
  //   component: Layout,
  //   redirect: '/example/table',
  //   name: 'Example',
  //   meta: { title: 'Example', icon: 'example' },
  //   children: [
  //     {
  //       path: 'table',
  //       name: 'Table',
  //       component: _import('table/index'),
  //       meta: { title: 'Table', icon: 'table' }
  //     },
  //     {
  //       path: 'tree',
  //       name: 'Tree',
  //       component: _import('tree/index'),
  //       meta: { title: 'Tree', icon: 'tree' }
  //     }
  //   ]
  // },

  // {
  //   path: '/form',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       name: 'Form',
  //       component: _import('form/index'),
  //       meta: { title: 'Form', icon: 'form' }
  //     }
  //   ]
  // },

  { path: '*', redirect: '/404', hidden: true }
]

export default new Router({
  // mode: 'history', //后端支持可开
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})

